/* Views
A SQL View is a virtual “table” of data that can be queried like a regular table. In most cases, the view contains specific columns of data from multiple tables. However, after the view has been completed, a simple query will allow for the display of its result set.

In this example, we create a view called “Teacher_Portal_Accounts”. It includes data from the STF, TCH, and UGN tables. After the view is created, we can query “Teacher_Portal_Accounts” to get the current data in those tables. Whenever the view is queried, the data that is returned is “real-time” data.
*/
if exists ((select top 1 1 from sys.objects o inner join sys.sql_modules m
on o.object_id = m.object_id
where o.[name] = 'Teacher_Portal_Accounts'
and o.[type_desc] in ('VIEW')

if exists (select top 1 1 from sys.objects o where o.[name] = 'Teacher_Portal_Accounts and o.[type_desc] = 'VIEW') 
begin drop view 'Teacher_Portal_Accounts' end; 




CREATE VIEW [dbo].[Teacher_Portal_Accounts] AS SELECT STF.ID AS 'Perm ID', TCH.SC AS 'School Code', TCH.TN AS 'Teacher #', TCH.TE AS 'Teacher Name', UGN.[UID] AS 'Portal Acct ID', UGN.UN AS 'Username', UGN.XD AS 'Expiration Date', UGN.PLC AS 'Password Last Changed Date' FROM TCH INNER JOIN STF ON TCH.ID = STF.ID INNER JOIN UGN ON STF.ID = UGN.[SID] WHERE STF.DEL = 0 AND TCH.DEL = 0 AND UGN.DEL = 0

SELECT * FROM Teacher_Portal_Accounts

/*
Two of the most common uses of a view for an Aeries database is for providing limited access to 3rd party vendors and running queries that are complex or run often. Some examples of more complex data groupsing that are pulled into views are found in a set of Views Jared as created that are available to be incorporated into Aeries.  These views make pulling data from other Aeries tables a bit more flexible.  These Views can be found on our website, this includes CONP, PGMS, GBKA and a few more:
https://support.aeries.com/support/solutions/articles/14000092446-aeries-query-expansion-through-sql-views-and-custom-tables

One last thought on use of Views, this is a great way to take something complex and store it for easy retrieval, however, I would warn against nested views as it can cause added headaches when trying to adjust data in the future.

*/

