/*
Now we are going to move to our next subject the use of CTEs 
Common Table Expressions are result sets defined at the front of the query (unlinke a subquery which is inline) 
Can be accessed by the query just as if they were tables.  
A CTE is introduced with the word WITH and the results are stored in a named temporary table.  
CTE's can be used recursively and are typically much easier to read.  
It also can be used many times within a query, as opposed to a subquery which can only be used once.  
I will also add CTE's do not necessarily result in improved performace over Subqueries.

I wanted start by showing a practical example of where I use CTE's.  In order to do so I want to look at HIS records.  I then want to 'accidently' mess up the records creating duplicates and then look at cleaning them up and then cleaning them up using a CTE */

USE DST23000AeriesDemo

/* Get a record count*/
SELECT * FROM HIS WHERE YR = 21 AND ST IN (994)

/*BACKUP HIS*/
SELECT * INTO HIS_BAK FROM HIS

/* Duplicates Records */
INSERT INTO HIS ([PID], [CN], [MK], [CR], [GR], [TE], [YR], [CO], [ST], [CC], [RT], [CI], [SQ], [EN], [PR], [TD], [AB], [EA], [UA], [SU], [SE], [SID], [HR], [SRC], [SDE], [ABG], [DC], [PF], [CH], [AC], [SA], [AMK], [MAG], [MAA], [DEL], [DTS])
SELECT [PID], [CN], [MK], [CR], [GR], [TE], [YR], [CO], [ST], [CC], [RT], [CI], [SQ]+1000, [EN], [PR], [TD], [AB], [EA], [UA], [SU], [SE], [SID], [HR], [SRC], [SDE], [ABG], [DC], [PF], [CH], [AC], [SA], [AMK], [MAG], [MAA], [DEL], [DTS] FROM HIS
WHERE YR = 21 AND ST IN (994)

/* Duplicates Records Yet Again */
INSERT INTO HIS ([PID], [CN], [MK], [CR], [GR], [TE], [YR], [CO], [ST], [CC], [RT], [CI], [SQ], [EN], [PR], [TD], [AB], [EA], [UA], [SU], [SE], [SID], [HR], [SRC], [SDE], [ABG], [DC], [PF], [CH], [AC], [SA], [AMK], [MAG], [MAA], [DEL], [DTS])
SELECT [PID], [CN], [MK], [CR], [GR], [TE], [YR], [CO], [ST], [CC], [RT], [CI], [SQ]+2000, [EN], [PR], [TD], [AB], [EA], [UA], [SU], [SE], [SID], [HR], [SRC], [SDE], [ABG], [DC], [PF], [CH], [AC], [SA], [AMK], [MAG], [MAA], [DEL], [DTS] FROM HIS
WHERE YR = 21 AND ST IN (994)

USE DST23000AeriesDemo
/* Show the record count */
SELECT * FROM HIS WHERE YR = 21 AND ST IN (994)

/* Back to the original group as each record is now there 4 times */
SELECT HIS.PID, HIS.CN, HIS.MK, HIS.CR, HIS.GR, HIS.TE, HIS.YR, HIS.ST, HIS.SE, HIS.SID, COUNT(*) AS CNT
FROM HIS 
WHERE YR = 21 AND ST IN (994)
GROUP BY HIS.PID, HIS.CN, HIS.MK, HIS.CR, HIS.GR, HIS.TE, HIS.YR, HIS.ST, HIS.SE, HIS.SID
HAVING COUNT (*) > 1; 
/* I could then go ahead and delete the records I do not need using a traditional query */


/* Using CTE to get our data - the output should match our select statement */
WITH CTE (PID, CN, MK, CR, GR, TE, YR, ST, SE, SID, DuplicateCount)
AS (SELECT HIS.PID, HIS.CN, HIS.MK, HIS.CR, HIS.GR, HIS.TE, HIS.YR, HIS.ST, HIS.SE, HIS.SID,
			ROW_NUMBER () OVER (PARTITION BY 
			HIS.PID, 
			HIS.CN,		
			HIS.MK, 
			HIS.CR, 
			HIS.GR, 
			HIS.TE, 
			HIS.YR, 
			HIS.ST, 
			HIS.SE, 
			HIS.SID
	ORDER BY PID) AS DuplicateCount
	FROM HIS WHERE YR = 21 AND ST IN (994))
SELECT * FROM CTE;

/* Delete using CTE to cleanup records */
WITH CTE (PID, CN, MK, CR, GR, TE, YR, ST, SE, SID, DuplicateCount)
AS (SELECT HIS.PID, HIS.CN, HIS.MK, HIS.CR, HIS.GR, HIS.TE, HIS.YR, HIS.ST, HIS.SE, HIS.SID,
			ROW_NUMBER () OVER (PARTITION BY 
			HIS.PID, 
			HIS.CN,		
			HIS.MK, 
			HIS.CR, 
			HIS.GR, 
			HIS.TE, 
			HIS.YR, 
			HIS.ST, 
			HIS.SE, 
			HIS.SID
	ORDER BY PID) AS DuplicateCount
	FROM HIS WHERE YR = 21 AND ST IN (994))
DELETE FROM CTE WHERE DuplicateCount > 1;

/*To run an update on DEL you would need to include DEL in the CTE and the query after it*/
WITH CTE (PID, CN, MK, CR, GR, TE, YR, ST, SE, SID, DEL,DuplicateCount)
AS (SELECT HIS.PID, HIS.CN, HIS.MK, HIS.CR, HIS.GR, HIS.TE, HIS.YR, HIS.ST, HIS.SE, HIS.SID, HIS.DEL,
			ROW_NUMBER () OVER (PARTITION BY 
			HIS.PID, 
			HIS.CN,		
			HIS.MK, 
			HIS.CR, 
			HIS.GR, 
			HIS.TE, 
			HIS.YR, 
			HIS.ST, 
			HIS.SE, 
			HIS.SID,
			HIS.DEL
	ORDER BY PID) AS DuplicateCount
	FROM HIS WHERE YR = 21 AND ST IN (994))
UPDATE CTE SET DEL = 1 WHERE DuplicateCount > 1;

/* I used similar logic in CTE's to check for duplicats in other tables as well.  
CAUTION: Know your data and where you expect to see duplication in the data and where you would not see it.  
Example, if I took the above CTE and cut it down to PID, CN 
I very well would expect to see duplicate records that are in fact valid records that I do not want to delete. */

/* ZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZ*/


/*Another example I use CTE's for is to get the contacts for SEIS queries.  
In this example I use mulitiple CTEs.  
Multiple CTEs can be used as well to combine data to offer easier to read code and flexibility.  
Note that when using multiple CTEs a comma is used to begin the second CTE. */

;WITH
cteSTU AS (
	SELECT
		STU.[ID]
		,STU.[SC]
		,STU.[SN]
		,STU.[GR]
		,STU.[FN]
		,STU.[LN]
		,STU.[MN]
		,STU.[FNA]
		,STU.[LNA]
		,STU.[MNA]
		,STU.[GN]
		,STU.[PED]
		,STU.[AD]
		,STU.[CY]
		,STU.[ST]
		,STU.[ZC]
		,STU.[SP]
		,STU.[RS]
		,STU.[HL]
		,STU.[ETH]
		,STU.[CID]
		,STU.[DEL]
	FROM
		STU
	WHERE
		STU.[DEL] = 0
		AND STU.[LN] <> '_'
		AND STU.[FN] <> '_'
		AND STU.[TG] = ''
		/* Only extract schools in School Group defined with @SchoolGroupCode */
		AND STU.[SC] IN (SELECT CD FROM LOC)
)
,cteCON AS (
	SELECT 
		ROW_NUMBER() OVER (PARTITION BY PID ORDER BY 
			[OR] 
			- CASE WHEN [PC]  = 'Y' THEN 1 ELSE 0 END
			- CASE WHEN [AP]  = 'Y' THEN 1 ELSE 0 END
			- CASE WHEN [LW]  = 'Y' THEN 1 ELSE 0 END
			- CASE WHEN [ERH] = 'Y' THEN 1 ELSE 0 END
			/* Uncomment this line like the one above if contact linking also makes them a more prominent contact? */
			/* - CASE WHEN  [C1D] <> '' OR [C2D] <> '' THEN 1 ELSE 0 END */
		) AS [ROWNUM]
		,[PID]
		,[LN]
		,[FN]
		,[AD]
		,[CY]
		,[ST]
		,[ZC]
		,[TL]
		,[CP]
		,[WP]
		,[RL]
		,[ELV]
		,[EM]
	FROM
		CON
	WHERE
		[DEL] = 0
		AND [RF] <> 1 
		AND [RL] IN ('10','11','12','13','14','15','21','22') /* LIMIT TO SPECIFIC RELATIONSHIP CODES WITH THIS LINE IF DESIRED */
		AND [CD] NOT IN (SELECT [CD] FROM COD WHERE [TC] = 'CON' AND [FC] = 'CD' AND [DEL] = 0 AND [N1] = 9)
		AND [PID] IN (SELECT DISTINCT [ID] FROM cteSTU WHERE [DEL] = 0)
)
SELECT
	STU.[ID] AS [LocalID]
	,STU.[CID] AS [SSID]
	,'' AS [SSN]
	,STU.[LN] AS [LastName]
	,STU.[FN] AS [FirstName]
	,STU.[MN] AS [MiddleName]
	,CASE
		WHEN STU.[ETH] IN ('Y', '1') THEN '500' /* Hispanic */
		WHEN STU.[ETH] IN ('N', '0') THEN '501' /* Non Hispanic */
		ELSE '900' /* Intentionally Blank */
	END AS [Ethnicity]
	,CON.[LN] AS [ContactLN]
	,CON.[FN] AS [CONTACTFN]
	FROM
		cteSTU AS STU
		INNER JOIN LOC ON STU.[SC] = LOC.[CD]
		INNER JOIN CSE ON STU.[ID] = CSE.[ID]
		INNER JOIN cteCON CON ON STU.ID = CON.PID
	WHERE
		STU.[DEL] = 0
		AND LOC.[DEL] = 0
		AND CSE.[DEL] = 0

/* ZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZ*/

/* A final example for CTEs is pulling FLEX Attendance data
Notice we are pulling the CAT date and tying it to MST and FTF 
in order to organize our schools, sections and periods.  We then
take that data and use it in an SQL statement to case out which
period to populate.  The output is "ReferenceCode","Institution","Periods"
In the CAT table each attendance line is one period so in order to populate
all of the lines into one some special attention had to be given.  
This may not be the only way to produce the results, but at the time when
I wrote this, using a CTE seemed the best way to accomplish this.
*/

	;WITH [cteCAT] AS (
		SELECT
			[CAT].*
			,[FTF].[TT] AS [PD]
			,ROW_NUMBER() OVER (PARTITION BY [CAT].[ID], [CAT].[SCL] ORDER BY [FTF].[ST]) AS [RowNum]
		FROM
			[CAT]
			INNER JOIN [MST] ON [CAT].[SCL] = [MST].[SC] AND [CAT].[SE] = [MST].[SE]
			INNER JOIN [FTF] ON [MST].[FSQ] = [FTF].[SQ]
		WHERE
			1=1
			AND [CAT].[DEL] = 0 AND [CAT].[DT] = cast(getdate() AS Date)
			AND CAT.AC IN ('A')
	)

	SELECT 
		Distinct cteCAT.ID as [ReferenceCode], 
		LOC.NM as [Institution],
		case when right((
				case WHEN (select '0' from cteCAT C0 WHERE C0.ID = cteCAT.ID AND C0.SCL = cteCAT.SCL AND C0.DT = cteCAT.DT AND C0.PD = 0) = 0 
					THEN '0, ' ELSE '' END + 
				case WHEN (select '1' from cteCAT C1 WHERE C1.ID = cteCAT.ID AND C1.SCL = cteCAT.SCL AND C1.DT = cteCAT.DT AND C1.PD = 1) = 1
					THEN '1, ' ELSE '' END + 
				case WHEN (select '2' from cteCAT C1 WHERE C1.ID = cteCAT.ID AND C1.SCL = cteCAT.SCL AND C1.DT = cteCAT.DT AND C1.PD = 2) = 2
					THEN '2, ' ELSE '' END + 
				case WHEN (select '3' from cteCAT C1 WHERE C1.ID = cteCAT.ID AND C1.SCL = cteCAT.SCL AND C1.DT = cteCAT.DT AND C1.PD = 3) = 3
					THEN '3, ' ELSE '' END + 
				case WHEN (select '4' from cteCAT C1 WHERE C1.ID = cteCAT.ID AND C1.SCL = cteCAT.SCL AND C1.DT = cteCAT.DT AND C1.PD = 4) = 4
					THEN '4, ' ELSE '' END + 
				case WHEN (select '5' from cteCAT C1 WHERE C1.ID = cteCAT.ID AND C1.SCL = cteCAT.SCL AND C1.DT = cteCAT.DT AND C1.PD = 5) = 5
					THEN '5, ' ELSE '' END + 
				case WHEN (select '6' from cteCAT C1 WHERE C1.ID = cteCAT.ID AND C1.SCL = cteCAT.SCL AND C1.DT = cteCAT.DT AND C1.PD = 6) = 6
					THEN '6, ' ELSE '' END + 
				case WHEN (select '7' from cteCAT C1 WHERE C1.ID = cteCAT.ID AND C1.SCL = cteCAT.SCL AND C1.DT = cteCAT.DT AND C1.PD = 7) = 7
					THEN '7' ELSE '' END),2) = ', '
			THEN 
				LEFT((case WHEN (select '0' from cteCAT C0 WHERE C0.ID = cteCAT.ID AND C0.SCL = cteCAT.SCL AND C0.DT = cteCAT.DT AND C0.PD = 0) = 0 
						THEN '0, ' ELSE '' END + 
					case WHEN (select '1' from cteCAT C1 WHERE C1.ID = cteCAT.ID AND C1.SCL = cteCAT.SCL AND C1.DT = cteCAT.DT AND C1.PD = 1) = 1
						THEN '1, ' ELSE '' END + 
					case WHEN (select '2' from cteCAT C1 WHERE C1.ID = cteCAT.ID AND C1.SCL = cteCAT.SCL AND C1.DT = cteCAT.DT AND C1.PD = 2) = 2
						THEN '2, ' ELSE '' END + 
					case WHEN (select '3' from cteCAT C1 WHERE C1.ID = cteCAT.ID AND C1.SCL = cteCAT.SCL AND C1.DT = cteCAT.DT AND C1.PD = 3) = 3
						THEN '3, ' ELSE '' END + 
					case WHEN (select '4' from cteCAT C1 WHERE C1.ID = cteCAT.ID AND C1.SCL = cteCAT.SCL AND C1.DT = cteCAT.DT AND C1.PD = 4) = 4
						THEN '4, ' ELSE '' END + 
					case WHEN (select '5' from cteCAT C1 WHERE C1.ID = cteCAT.ID AND C1.SCL = cteCAT.SCL AND C1.DT = cteCAT.DT AND C1.PD = 5) = 5
						THEN '5, ' ELSE '' END + 
					case WHEN (select '6' from cteCAT C1 WHERE C1.ID = cteCAT.ID AND C1.SCL = cteCAT.SCL AND C1.DT = cteCAT.DT AND C1.PD = 6) = 6
						THEN '6, ' ELSE '' END + 
					case WHEN (select '7' from cteCAT C1 WHERE C1.ID = cteCAT.ID AND C1.SCL = cteCAT.SCL AND C1.DT = cteCAT.DT AND C1.PD = 7) = 7
						THEN '7' ELSE '' END),
					LEN ((case WHEN (select '0' from cteCAT C0 WHERE C0.ID = cteCAT.ID AND C0.SCL = cteCAT.SCL AND C0.DT = cteCAT.DT AND C0.PD = 0) = 0 
						THEN '0, ' ELSE '' END + 
					case WHEN (select '1' from cteCAT C1 WHERE C1.ID = cteCAT.ID AND C1.SCL = cteCAT.SCL AND C1.DT = cteCAT.DT AND C1.PD = 1) = 1
						THEN '1, ' ELSE '' END + 
					case WHEN (select '2' from cteCAT C1 WHERE C1.ID = cteCAT.ID AND C1.SCL = cteCAT.SCL AND C1.DT = cteCAT.DT AND C1.PD = 2) = 2
						THEN '2, ' ELSE '' END + 
					case WHEN (select '3' from cteCAT C1 WHERE C1.ID = cteCAT.ID AND C1.SCL = cteCAT.SCL AND C1.DT = cteCAT.DT AND C1.PD = 3) = 3
						THEN '3, ' ELSE '' END + 
					case WHEN (select '4' from cteCAT C1 WHERE C1.ID = cteCAT.ID AND C1.SCL = cteCAT.SCL AND C1.DT = cteCAT.DT AND C1.PD = 4) = 4
						THEN '4, ' ELSE '' END + 
					case WHEN (select '5' from cteCAT C1 WHERE C1.ID = cteCAT.ID AND C1.SCL = cteCAT.SCL AND C1.DT = cteCAT.DT AND C1.PD = 5) = 5
						THEN '5, ' ELSE '' END + 
					case WHEN (select '6' from cteCAT C1 WHERE C1.ID = cteCAT.ID AND C1.SCL = cteCAT.SCL AND C1.DT = cteCAT.DT AND C1.PD = 6) = 6
						THEN '6, ' ELSE '' END + 
					case WHEN (select '7' from cteCAT C1 WHERE C1.ID = cteCAT.ID AND C1.SCL = cteCAT.SCL AND C1.DT = cteCAT.DT AND C1.PD = 7) = 7
						THEN '7' ELSE '' END))-1)
					ELSE 
					case WHEN (select '0' from cteCAT C0 WHERE C0.ID = cteCAT.ID AND C0.SCL = cteCAT.SCL AND C0.DT = cteCAT.DT AND C0.PD = 0) = 0 
						THEN '0, ' ELSE '' END + 
					case WHEN (select '1' from cteCAT C1 WHERE C1.ID = cteCAT.ID AND C1.SCL = cteCAT.SCL AND C1.DT = cteCAT.DT AND C1.PD = 1) = 1
						THEN '1, ' ELSE '' END + 
					case WHEN (select '2' from cteCAT C1 WHERE C1.ID = cteCAT.ID AND C1.SCL = cteCAT.SCL AND C1.DT = cteCAT.DT AND C1.PD = 2) = 2
						THEN '2, ' ELSE '' END + 
					case WHEN (select '3' from cteCAT C1 WHERE C1.ID = cteCAT.ID AND C1.SCL = cteCAT.SCL AND C1.DT = cteCAT.DT AND C1.PD = 3) = 3
						THEN '3, ' ELSE '' END + 
					case WHEN (select '4' from cteCAT C1 WHERE C1.ID = cteCAT.ID AND C1.SCL = cteCAT.SCL AND C1.DT = cteCAT.DT AND C1.PD = 4) = 4
						THEN '4, ' ELSE '' END + 
					case WHEN (select '5' from cteCAT C1 WHERE C1.ID = cteCAT.ID AND C1.SCL = cteCAT.SCL AND C1.DT = cteCAT.DT AND C1.PD = 5) = 5
						THEN '5, ' ELSE '' END + 
					case WHEN (select '6' from cteCAT C1 WHERE C1.ID = cteCAT.ID AND C1.SCL = cteCAT.SCL AND C1.DT = cteCAT.DT AND C1.PD = 6) = 6
						THEN '6, ' ELSE '' END + 
					case WHEN (select '7' from cteCAT C1 WHERE C1.ID = cteCAT.ID AND C1.SCL = cteCAT.SCL AND C1.DT = cteCAT.DT AND C1.PD = 7) = 7
						THEN '7' ELSE '' END
		END  [Periods]
	FROM cteCAT 
		INNER JOIN LOC ON cteCAT.SCL = LOC.CD
	WHERE 
		cteCAT.DT = cast(getdate() AS Date) 
		AND cteCAT.SCL IN (1,2)
		
/* A recursive CTE is a CTE that references itself. A recursive CTE can join a table to itself as many times as necessary to process hierarchical data in the table. */

--Aeries.NET Effective Permissions Query -- Aeries Software - Jared Kuszewski 2015-05-06 -revised 02/13/2018

declare @TeacherSCH smallint
declare @YR smallint
--##########################################################
--Teacher permissions are school specific   SET THE @TeacherSCH school number in the next line
set @TeacherSCH = 994
--Pick 0 for current Years or (1 or 2) for evaluating 1 or 2 years prior. 2 is all years 2 or more years old in the past
set @YR = 0
--##########################################################

if (select @TeacherSCH) is null goto TeachSCH_unspecified

;WITH UGA_recursed ([UID], gid, GroupLevel, FromGroup)
AS (SELECT [UID], GID, 1 as GroupLevel, null as FromGroup FROM dbo.UGA WHERE DEL = 0
UNION ALL
SELECT UGA_recursed.[UID], UGA.GID, GroupLevel + 1, uga.uid FromGroup
FROM dbo.UGA INNER JOIN UGA_recursed ON UGA_recursed.gid = UGA.[UID] WHERE UGA.del = 0)
, SchoolsInUSR (un, SchPerms)
as
(select un, case 
when uty like '%admin' then 'AdminHasAll'
when uty like '%user' then 
isnull(
stuff(
(select ',' + cast(sch as varchar(4)) from usr where nm = ugn.un and del = 0 order by sch for xml path(''))
,1,1,'') 
,'')  
when uty like '%teacher' then
isnull(
stuff(
(select ',' + cast(sc as varchar(4)) from tch where (id = ugn.sid or id2 = ugn.sid or id3 = ugn.sid) and del = 0 group by sc order by sc for xml path(''))
,1,1,'') 
,'')  
else '' end SchPerms
from ugn
where ty = 1 and st = 0 and del = 0 and (xd > CURRENT_TIMESTAMP or xd is null))


select UN, FN, LN, EM, UTY, TC, FC, 
case when max(RD) = 2 then 'Denied' when max(RD) = 1 then 'Read' else '' end as [READ],
case when max(UP) = 2 then 'Denied' when max(UP) = 1 then 'Update' else '' end as [UPDATE],
case when max(INS) = 2 then 'Denied' when max(INS) = 1 then 'Insert' else '' end as [INSERT],
case when max(DL) = 2 then 'Denied' when max(DL) = 1 then 'Delete' else '' end as [DELETE],
case when max(MU) = 2 then 'Denied' when max(MU) = 1 then 'MassUpd' else '' end as [MassUpd],
case when max(AD) = 2 then 'Denied' when max(AD) = 1 then 'Administer' else '' end as [Adminst]
, SchPerms

from

(select UGN.[UID], UGN.UN, UGN.FN, UGN.LN, UGN.EM, UGN.UTY, uga_recursed.GID as GID, gugn.un as GNAME, UGP.TC, UGP.FC, UGP.RD, UGP.UP, UGP.INS, UGP.DL, UGP.MU, UGP.AD, SchPerms
from ugn inner join uga_recursed on uga_recursed.[UID] = ugn.[UID]
inner join ugn as gugn on uga_recursed.gid = gugn .[UID]
inner join ugp on uga_recursed.gid = ugp.[UID]
left join SchoolsInUSR on SchoolsInUSR.un = ugn.un
where ugn.del = 0 and gugn.del = 0 and gugn.st = 0 and ugp.del = 0 and ugp.yr = @YR

union all

--Explicit Permissions given directly to a user
select UGN.[UID], UGN.UN, UGN.FN, UGN.LN, UGN.EM, UGN.UTY, 0 as GID, cast('SELF' as varchar (255)) as GNAME, UGP.TC, UGP.FC, UGP.RD, UGP.UP, UGP.INS, UGP.DL, UGP.MU, UGP.AD, SchPerms
from ugn left join ugp on ugn.[UID] = ugp.[UID]
left join SchoolsInUSR on SchoolsInUSR.un = ugn.un
where ugn.del = 0 and ugn.ty = 1 and ( ugp.del = 0 or UGP.DEL is null) and ugp.yr = @YR

union all 

--Teacher Permissions (portal groups are not capable of inheriting)
select UGN.[UID], UGN.UN, UGN.FN, UGN.LN, UGN.EM, UGN.UTY, (select min([UID]) from ugn where un = 'Teachers' and ty = 2 and del = 0) as GID, cast('Teachers' as varchar (255)) as GNAME, UGP.TC, UGP.FC, UGP.RD, UGP.UP, UGP.INS, UGP.DL, UGP.MU, UGP.AD, SchPerms
from ugn cross join ugp
left join SchoolsInUSR on SchoolsInUSR.un = ugn.un
where ugn.del = 0 and ugn.ty = 1 and uty like '%Teacher' and ( ugp.del = 0 or UGP.DEL is null) and ugp.[UID] = (select top 1 [UID] from ugn where un = 'Teachers' and del = 0 order by uid) and ugp.sc = @TeacherSCH and ugp.yr = @YR

union all 

--Substitute Teacher Permissions (portal groups are not capable of inheriting)
select UGN.[UID], UGN.UN, UGN.FN, UGN.LN, UGN.EM, UGN.UTY, (select min([UID]) from ugn where un = 'Substitute Teachers' and ty = 2 and del = 0) as GID, cast('Substitute Teachers' as varchar (255)) as GNAME, UGP.TC, UGP.FC, UGP.RD, UGP.UP, UGP.INS, UGP.DL, UGP.MU, UGP.AD, SchPerms
from ugn cross join ugp
left join SchoolsInUSR on SchoolsInUSR.un = ugn.un
where ugn.del = 0 and ugn.ty = 1 and uty like '%Teachersub' and ( ugp.del = 0 or UGP.DEL is null) and ugp.[UID] = (select top 1 [UID] from ugn where un = 'Substitute Teachers' and del = 0 order by uid) and ugp.sc = @TeacherSCH and ugp.yr = @YR

) as AllPermissions

--un remark and use option on next line to lookup just one user
--where un = 'TheirUserName'

group by UN, FN, LN, EM, UTY, TC, FC, SchPerms
order by UN, FN, LN, EM, UTY, TC, FC, SchPerms

goto ending

TeachSCH_unspecified:
print 'TeacherSCH not specified - Unable to evaluate teacher permissions without specifying a school at the top of script'

Ending:
		