/*Window Functions are a type of function in SQL that performs a calculation across a set of rows.  
These functions operate on a subset of rows, called a window, that is defined by an over() clause.  
I am only touching on a few of these functions, 
the SQL Intermediate class taught by Sarah on Friday, Period 3 will discuss other Windows functions.

If you notice within our HIS CTE we used a Window function 
OVER, PARTITION and ORDER BY

This allows us to take a group of records in HIS, give them a row number and ORDER them.  
In this instance we use that to get any duplicate records grouped.
We can then delete tag, or delete those records. */

WITH CTE (PID, CN, MK, CR, GR, TE, YR, ST, SE, SID, DuplicateCount)
AS (SELECT HIS.PID, HIS.CN, HIS.MK, HIS.CR, HIS.GR, HIS.TE, HIS.YR, HIS.ST, HIS.SE, HIS.SID,
			ROW_NUMBER () OVER (PARTITION BY 
			HIS.PID, 
			HIS.CN,		
			HIS.MK, 
			HIS.CR, 
			HIS.GR, 
			HIS.TE, 
			HIS.YR, 
			HIS.ST, 
			HIS.SE, 
			HIS.SID
	ORDER BY PID) AS DuplicateCount
	FROM HIS WHERE YR = 21 AND ST IN (994))
SELECT * FROM CTE;

/* We can also use ROW_NUMBER to rank test scores, however, using the RANK or DENSE_RANK may be preferred */

SELECT PID, ID, PT, GR, DT, RS, SS, PL, ROW_NUMBER()
OVER (ORDER BY SS DESC) as rank
FROM TST WHERE ID = 'CST' and PT = 1 AND GR = 10 and TA = 'SPRG22'

/* Other Windows Functions include Rank and Dense Rank that can also be used for similar results depending on your needs */
SELECT PID, ID, PT, GR, DT, RS, SS, PL, RANK()
OVER (ORDER BY SS DESC) as rank
FROM TST WHERE ID = 'CST' and PT = 1 AND GR = 10 and TA = 'SPRG22'

SELECT PID, ID, PT, GR, DT, RS, SS, PL, DENSE_RANK()
OVER (ORDER BY SS DESC) as rank
FROM TST WHERE ID = 'CST' and PT = 1 AND GR = 10 and TA = 'SPRG22'

/* Notice how in Rank you see the count jump when the same rank is used. 
DENSE_RANK() uses the next consecutive rank number.  
Percentile Rank is another Windows Function. 
NTILE() will divide your window group into a specified number of groups.
So NTILE(4) would break our results into 4 groups based on the Scaled Score much like a performance LEVEL.
This could be used to identify the top quarter of scores or the lower quarter to provide additional support */

/* ZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZZ*/
/* Another valuable use of ROW_NUMBER is in generating a sequence (SQ)  
I wanted to provide 
*/
-- wrong way #1  
select pid, dt, sq, (select max(sq) from ads as subads where ads.pid = subads.pid) + 1 as NewSQ
from DST23000AeriesDemo..ads

-- better method, has some issues
select pid, dt, sq, ROW_NUMBER() over (partition by pid order by dt) + (select max(sq) from ads as subads where ads.pid = subads.pid) as BetterSQ
from DST23000AeriesDemo..ads		--																				^--- why not check for del-tagged records?
--Some SQs will be NULL if the origin table has 0 records to start with, so the correct query would be:
select pid, dt, sq, ROW_NUMBER() over (partition by pid order by dt) + isnull((select max(sq) from ads as subads where ads.pid = subads.pid),0) as BestSQ
from DST23000AeriesDemo..ads

