/*
CURSOR: Cursor is a Temporary Memory or Temporary Work Station. 
It is Allocated by Database Server at the Time of Performing DML(Data Manipulation Language) 
	operations on the Table by the User. 
Cursors are used to store Database Tables.

Just as a quick note, we have variables being used in this query.  
I am not covering variables in this session, however, in the SQL Intermediate Course, which is Friday Period 3  
I do plan to show a series of variables that I keep and reuse as needed later.
*/


DECLARE @ID   INT
DECLARE @FN   NVARCHAR(50)
DECLARE @LN   NVARCHAR(50)
DECLARE @NAME NVARCHAR(100)

DECLARE varCursor CURSOR FOR
SELECT ID, LN, FN FROM STU WHERE DEL = 0 AND TG = ''

OPEN varCursor

FETCH NEXT FROM varCursor INTO @ID, @LN, @FN

WHILE @@FETCH_STATUS = 0
BEGIN

	SET @NAME = @FN + ' ' + @LN
	PRINT 'Hello ' + @NAME + '!'

	FETCH NEXT FROM varCursor INTO @ID, @LN, @FN

END

CLOSE varCursor
DEALLOCATE varCursor


/*  SQL Server Cursor Limitations
Cursors have some limitations, it should only be used when there is no other choice. 
These restrictions include:
	When processing data, it imposes locks on a subset or the entire table.
	The cursor updates table records one row at a time, which slows down its performance.
	While loops are slower than cursors, they do have more overhead.
	Another factor that influences cursor speed is the quantity of rows and columns brought into the cursor. 
*/
