/ * The Stored procedure is used to save time to write the code, again and again. It does this by storing the procedure in database and get the required output by passing the parameters.   Stored procedures are similar to SQL Queries.
However, there are a few major differences between a stored procedure and a SQL query: A stored procedure is invoked as a function call instead of a SQL query. 

*/
/* Analytics Grade Indicators where the qualifying value or level is less that the average (by indicator/subject) */

DROP PROCEDURE IF EXISTS [Analytics_GradeIndicator];
GO

CREATE PROCEDURE [dbo].[Analytics_GradeIndicator] @indicatorAID nvarchar(50)
AS
SELECT * FROM (
	SELECT 
		 STU.ID, STU.LN, STU.FN, STU.GR, STU.GN, D.TI, D.LVL, D.QV
		,AVG(D.LVL) OVER (PARTITION BY D.SCL, STU.GR ORDER BY D.SCL, STU.GR) AS 'Qualifying Level' --Average qualifying level by grade
		,AVG(D.QV)  OVER (PARTITION BY D.SCL, STU.GR ORDER BY D.SCL, STU.GR) AS 'Qualifying Value' --Average qualifying value by grade
	FROM STU INNER JOIN (SELECT I.TI, DAQ.ID, DAQ.SQ, DAQ.AID, DAQ.D1, DAQ.D2, DAQ.SCL, DAQ.GR, DAQ.LVL
							,CASE
								WHEN DAQ.QV LIKE 'A%' THEN 4
								WHEN DAQ.QV LIKE 'B%' THEN 3
								WHEN DAQ.QV LIKE 'C%' THEN 2
								WHEN DAQ.QV LIKE 'D%' THEN 1
								ELSE 0
							END QV
						FROM DAQ INNER JOIN (SELECT AID, TI FROM DAI WHERE DEL = 0) I 
							ON DAQ.AID = I.AID
						WHERE DAQ.AID = @indicatorAID AND DAQ.ID IN (SELECT ID FROM STU WHERE DEL = 0 AND SC IN (SELECT CD FROM LOC WHERE E IN (2, 3)))
						) D
		ON STU.ID = D.ID AND STU.SC = D.SCL) X
WHERE X.LVL < X.[Qualifying Level] OR X.QV < X.[Qualifying Value]


--EXEC Analytics_GradeIndicator @indicatorAID=N'edaff600-5a29-47fe-b189-79380de56b98'

/*
d9558dd2-1523-4746-a8ed-d350eb5f148b
1303f3e9-0337-4034-9cd6-9ee351a1e48
edaff600-5a29-47fe-b189-79380de56b98
1763f0dd-fe84-439d-b7c2-904285445d70
1376655a-26bb-4107-917c-4c69de102f53
a6f12050-8719-465b-bf4e-e116b23d1cbd
2aa99188-adda-4a1b-8963-5758c2a1827b
ef1959f8-2620-4117-b40a-30044b0f0a96
1feb46c6-9fad-45fd-9613-f1a808dbda67
89c906ad-f0d0-4ac0-9b40-bee4c62dd9ca
ac235c02-6750-4b3f-b13a-f579e3c28471
aaee6669-d585-4157-9e25-227365b27a0d
4166909d-290c-42e1-9d52-011233f930d6
bf5b71da-c731-4815-8602-81df26d42ea9
*/

/* Above shows how to CREATE and DROP a stored procedure.
To modify a stored procedure you would use ALTER PROCEDURE  */




